==> LL_utils-4.1.1.4-power-Linux-RHEL6.tar.gz: var/www/ll/cgi-bin/pull_down_tab_panel_users.pl <==
#!/usr/bin/perl

# static char sccsid[] = "@(#)31 1.8 src/ll/config_editor/cgi-bin/pull_down_tab_panel_users.pl, ll.config, ll_rrur2, rrur21042a 1/2/10 03:58:03\n";

use strict;
use lib "/var/www/ll/cgi-bin";
use LLUtil;
use DBI;

my ($mysql_host, $mysql_user, $mysql_pass, $mysql_db) = get_db_info(0);

my @normal_tables_by_userID = @{LLUtil::ALL_TABLES->{"tab_panel_users"}->[0]};

my $query = $ENV{QUERY_STRING};
$query = unescape($query);

$_ = $query;
if(/id=(\d+)&name=(.*)&cluster=(\d+)/)
{
	my $json_str_0 = "Content-type: text/html\n\n";
	my $dbh = DBI->connect("DBI:mysql:database=$mysql_db;host=$mysql_host",$mysql_user,$mysql_pass);
	if(!defined($dbh))
	{
		my $json_str_err = $json_str_0."Error:".DBI->errstr;
		print $json_str_err;
		exit 1;
	}
	
	my $userID = $1;
	my $option_name = $2;
	my $cluster_id = $3;

	my $sql_str;
	my $sth;

	my $json_str = $json_str_0."[";

	# Get default user id
	my $default_user_id = undef;
	if($userID != 0)
	{
		$default_user_id = get_default_id_by_primary_key($dbh,"userID","clusterID","TLLS_CFGUser","name",$userID);
	}
	else
	{
		$default_user_id = get_default_id($dbh,"userID","name","TLLS_CFGUser",$cluster_id);
	}
	
	# Get default values
	if(defined($default_user_id))
	{
		my $is_default = 0;
		if($default_user_id == $userID) { $is_default = 1; }
		$json_str .= get_default_json_str($dbh,"tab_panel_users","userID",$default_user_id,$is_default);
	}		

	if($userID != 0)
	{
		
	foreach my $table (@normal_tables_by_userID)
	{
		$sql_str="select * from ".$table." where userID=".$userID;
		$sth=$dbh->prepare($sql_str);
		if(!defined($sth->execute()))
		{
			my $json_str_err = $json_str_0."Error:".$dbh->errstr;
			print $json_str_err;
			exit 1;
		}
		my $ary_ref = $sth->fetchrow_arrayref;
		my $i = 0;
		$json_str .= "{type:'normal',id:'".$table."-id"."',value:'".$userID."'},";
		if(exists $ary_ref->[$i])
		{
			for($i=1;$i<$sth->{NUM_OF_FIELDS};$i++)
			{
				$json_str .= "{type:'normal',id:'".$table."-".$sth->{NAME}->[$i]."',value:'".$ary_ref->[$i]."'},";
			}
		}
	}

	} # $userID != 0
	
	$json_str =~ s/,$//g;
	$json_str .= "]";
	if(defined($sth)) {$sth->finish();}
	print $json_str;
	$dbh->disconnect();

}

==> LL_utils-5.1.0.17-power-Linux-RHEL6.tar.gz: var/www/ll/cgi-bin/pull_down_tab_panel_users.pl <==
#!/usr/bin/perl

# static char sccsid[] = "@(#)31 1.9 src/ll/config_editor/cgi-bin/pull_down_tab_panel_users.pl, ll.config, ll_rrnep2, rrnep21206a 9/26/10 16:31:49\n";

use strict;
use lib "/var/www/ll/cgi-bin";
use LLUtil;
use DBI;

my ($db_host, $db_user, $db_pass, $db_db, $db_conn, $db2inst) = get_db_info(0);

my @normal_tables_by_userID = @{LLUtil::ALL_TABLES->{"tab_panel_users"}->[0]};

my $query = $ENV{QUERY_STRING};
$query = unescape($query);

$_ = $query;
if(/id=(\d+)&name=(.*)&cluster=(\d+)/)
{
	my $json_str_0 = "Content-type: text/html\n\n";
	my $dbh = get_dbh(0);
	if(!defined($dbh))
	{
		error_and_exit($dbh->errstr);
	}
	
	my $userID = $1;
	my $option_name = $2;
	my $cluster_id = $3;

	my $sql_str;
	my $sth;

	my $json_str = $json_str_0."[";

	# Get default user id
	my $default_user_id = undef;
	if($userID != 0)
	{
		$default_user_id = get_default_id_by_primary_key($dbh,"userID","clusterID","TLLS_CFGUser","name",$userID);
	}
	else
	{
		$default_user_id = get_default_id($dbh,"userID","name","TLLS_CFGUser",$cluster_id);
	}
	
	# Get default values
	if(defined($default_user_id))
	{
		my $is_default = 0;
		if($default_user_id == $userID) { $is_default = 1; }
		$json_str .= get_default_json_str($dbh,"tab_panel_users","userID",$default_user_id,$is_default);
	}		

	if($userID != 0)
	{
		
	foreach my $table (@normal_tables_by_userID)
	{
		$sql_str="select * from ".$table." where userID=".$userID;
		$sth=$dbh->prepare($sql_str);
		if(!defined($sth->execute()))
		{
			my $json_str_err = $json_str_0."Error:".$dbh->errstr;
			print $json_str_err;
			exit 1;
		}
		my $ary_ref = $sth->fetchrow_arrayref;
		my $i = 0;
		$json_str .= "{type:'normal',id:'".$table."-id"."',value:'".$userID."'},";
		if(exists $ary_ref->[$i])
		{
			for($i=1;$i<$sth->{NUM_OF_FIELDS};$i++)
			{
				$json_str .= "{type:'normal',id:'".$table."-".$sth->{NAME}->[$i]."',value:'".$ary_ref->[$i]."'},";
			}
		}
	}

	} # $userID != 0
	
	$json_str =~ s/,$//g;
	$json_str .= "]";
	if(defined($sth)) {$sth->finish();}
	print $json_str;
	$dbh->disconnect();

}
